@@ -40,13 +40,13 @@ class Retriever(threading.Thread):
     return it to the Reader when a new subscription arrives
     """
 
-    def __init__(self, feed, do_retention=True):
+    def __init__(self, feed, feed_from_db=None, do_retention=True):
         threading.Thread.__init__(self)
         # self.feed is raw parsed feed
-        self.feed = feed
-        self.title = feed.feed['title']
         self.data = feed['entries']
         self.do_retention = do_retention
+        if feed_from_db:
+            self.title = feed_from_db['title']
 
     def run(self):
         # This feed comes from database
@@ -72,9 +72,9 @@ class Retriever(threading.Thread):
                 published_datetime = datetime.datetime.now()
 
             if self.do_retention:
-                delta = published_datetime - datetime.datetime.now()
-                if delta.days < -int(config.get('worker', 'retention')):
-                    break
+                delta = datetime.datetime.now() - published_datetime
+                if delta.days > int(config.get('worker', 'retention')):
+                    continue
 
             storage.add_story({
                 'title': title,
@@ -131,7 +131,7 @@ class Refresher(threading.Thread):
                     readed.append(entry['title'])
                 storage.remove_story(entry['_id'])
 
-            retriever = Retriever(self.data)
+            retriever = Retriever(self.data, self.feed, do_retention=False)
             retriever.start()
             retriever.join()
 
@@ -162,7 +162,7 @@ class Reader(object):
         resp = requests.get(stripped)
         feed = feedparser.parse(resp.text)
         if feed.version != '':
-            return feed
+            return feed, stripped
 
         urls = FeedFinder.parse(resp.text)
         feed_url = ''
@@ -174,10 +174,10 @@ class Reader(object):
             if urlparse(feed_url)[1] == '':
                 # We have empty 'netloc', meaning we have relative url
                 feed_url = urljoin(stripped, feed_url)
-        return feedparser.parse(feed_url)
+        return feedparser.parse(feed_url), feed_url
 
     def add(self, url):
-        feed = self.get_feed(url)
+        feed, url = self.get_feed(url)
 
         # Bad feed
         if feed.version == '' or not feed.feed.get('title'):
